var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'ad.xml',
'vecad.xml'
];
var list_down2 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'multi_thread.xml',
'library.xml',
'cppad_ipopt_nlp.xml',
'example.xml',
'preprocessor.xml',
'appendix.xml'
];
var list_down1 = [
'default.xml',
'ad_copy.xml',
'convert.xml',
'advalued.xml',
'boolvalued.xml',
'vecad.xml',
'base_require.xml'
];
var list_down0 = [
'vec_ad.cpp.xml'
];
var list_current0 = [
'vecad.xml#Syntax',
'vecad.xml#Purpose',
'vecad.xml#Alternatives',
'vecad.xml#VecAD&lt;Base&gt;::reference',
'vecad.xml#VecAD&lt;Base&gt;::reference.Exceptions',
'vecad.xml#Constructor',
'vecad.xml#Constructor.v',
'vecad.xml#n',
'vecad.xml#size',
'vecad.xml#size_t Indexing',
'vecad.xml#size_t Indexing.i',
'vecad.xml#size_t Indexing.b',
'vecad.xml#AD Indexing',
'vecad.xml#AD Indexing.x',
'vecad.xml#AD Indexing.r',
'vecad.xml#Example',
'vecad.xml#Speed and Memory'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
